@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2018-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2018-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -44,18 +44,11 @@ void testing_rotmg_strided_batched_bad_arg(const Arguments& arg)
     rocblas_local_handle handle{arg};
 
     // Allocate device memory
-    device_strided_batch_vector<T> d1(1, 1, stride_d1, batch_count);
-    device_strided_batch_vector<T> d2(1, 1, stride_d2, batch_count);
-    device_strided_batch_vector<T> dx(1, 1, stride_x, batch_count);
-    device_strided_batch_vector<T> dy(1, 1, stride_y, batch_count);
-    device_strided_batch_vector<T> dparams(5, 1, stride_param, batch_count);
-
-    // Check device memory allocation
-    CHECK_DEVICE_ALLOCATION(d1.memcheck());
-    CHECK_DEVICE_ALLOCATION(d2.memcheck());
-    CHECK_DEVICE_ALLOCATION(dx.memcheck());
-    CHECK_DEVICE_ALLOCATION(dy.memcheck());
-    CHECK_DEVICE_ALLOCATION(dparams.memcheck());
+    DEVICE_MEMCHECK(device_strided_batch_vector<T>, d1, (1, 1, stride_d1, batch_count));
+    DEVICE_MEMCHECK(device_strided_batch_vector<T>, d2, (1, 1, stride_d2, batch_count));
+    DEVICE_MEMCHECK(device_strided_batch_vector<T>, dx, (1, 1, stride_x, batch_count));
+    DEVICE_MEMCHECK(device_strided_batch_vector<T>, dy, (1, 1, stride_y, batch_count));
+    DEVICE_MEMCHECK(device_strided_batch_vector<T>, dparams, (5, 1, stride_param, batch_count));
 
     DAPI_EXPECT(rocblas_status_invalid_handle,
                 rocblas_rotmg_strided_batched_fn,
@@ -121,39 +114,33 @@ void testing_rotmg_strided_batched(const Arguments& arg)
     }
 
     // Initial Data on CPU
-    host_strided_batch_vector<T> hd1(1, 1, stride_d1, batch_count);
-    host_strided_batch_vector<T> hd2(1, 1, stride_d2, batch_count);
-    host_strided_batch_vector<T> hx(1, 1, stride_x, batch_count);
-    host_strided_batch_vector<T> hy(1, 1, stride_y, batch_count);
-    host_strided_batch_vector<T> hparams(5, 1, stride_param, batch_count);
+    HOST_MEMCHECK(host_strided_batch_vector<T>, hd1, (1, 1, stride_d1, batch_count));
+    HOST_MEMCHECK(host_strided_batch_vector<T>, hd2, (1, 1, stride_d2, batch_count));
+    HOST_MEMCHECK(host_strided_batch_vector<T>, hx, (1, 1, stride_x, batch_count));
+    HOST_MEMCHECK(host_strided_batch_vector<T>, hy, (1, 1, stride_y, batch_count));
+    HOST_MEMCHECK(host_strided_batch_vector<T>, hparams, (5, 1, stride_param, batch_count));
 
     // Allocate device memory
-    device_strided_batch_vector<T> dd1(1, 1, stride_d1, batch_count);
-    device_strided_batch_vector<T> dd2(1, 1, stride_d2, batch_count);
-    device_strided_batch_vector<T> dx(1, 1, stride_x, batch_count);
-    device_strided_batch_vector<T> dy(1, 1, stride_y, batch_count);
-    device_strided_batch_vector<T> dparams(5, 1, stride_param, batch_count);
-
-    // Check device memory allocation
-    CHECK_DEVICE_ALLOCATION(dd1.memcheck());
-    CHECK_DEVICE_ALLOCATION(dd2.memcheck());
-    CHECK_DEVICE_ALLOCATION(dx.memcheck());
-    CHECK_DEVICE_ALLOCATION(dy.memcheck());
-    CHECK_DEVICE_ALLOCATION(dparams.memcheck());
+    DEVICE_MEMCHECK(device_strided_batch_vector<T>, dd1, (1, 1, stride_d1, batch_count));
+    DEVICE_MEMCHECK(device_strided_batch_vector<T>, dd2, (1, 1, stride_d2, batch_count));
+    DEVICE_MEMCHECK(device_strided_batch_vector<T>, dx, (1, 1, stride_x, batch_count));
+    DEVICE_MEMCHECK(device_strided_batch_vector<T>, dy, (1, 1, stride_y, batch_count));
+    DEVICE_MEMCHECK(device_strided_batch_vector<T>, dparams, (5, 1, stride_param, batch_count));
 
     if(arg.unit_check || arg.norm_check)
     {
-        host_strided_batch_vector<T> hd1_gold(1, 1, stride_d1, batch_count);
-        host_strided_batch_vector<T> hd2_gold(1, 1, stride_d2, batch_count);
-        host_strided_batch_vector<T> hx_gold(1, 1, stride_x, batch_count);
-        host_strided_batch_vector<T> hy_gold(1, 1, stride_y, batch_count);
-        host_strided_batch_vector<T> hparams_gold(5, 1, stride_param, batch_count);
+        HOST_MEMCHECK(host_strided_batch_vector<T>, hd1_gold, (1, 1, stride_d1, batch_count));
+        HOST_MEMCHECK(host_strided_batch_vector<T>, hd2_gold, (1, 1, stride_d2, batch_count));
+        HOST_MEMCHECK(host_strided_batch_vector<T>, hx_gold, (1, 1, stride_x, batch_count));
+        HOST_MEMCHECK(host_strided_batch_vector<T>, hy_gold, (1, 1, stride_y, batch_count));
+        HOST_MEMCHECK(
+            host_strided_batch_vector<T>, hparams_gold, (5, 1, stride_param, batch_count));
 
-        host_strided_batch_vector<T> rd1(1, 1, stride_d1, batch_count);
-        host_strided_batch_vector<T> rd2(1, 1, stride_d2, batch_count);
-        host_strided_batch_vector<T> rx(1, 1, stride_x, batch_count);
-        host_strided_batch_vector<T> ry(1, 1, stride_y, batch_count);
-        host_strided_batch_vector<T> rparams(5, 1, stride_param, batch_count);
+        HOST_MEMCHECK(host_strided_batch_vector<T>, rd1, (1, 1, stride_d1, batch_count));
+        HOST_MEMCHECK(host_strided_batch_vector<T>, rd2, (1, 1, stride_d2, batch_count));
+        HOST_MEMCHECK(host_strided_batch_vector<T>, rx, (1, 1, stride_x, batch_count));
+        HOST_MEMCHECK(host_strided_batch_vector<T>, ry, (1, 1, stride_y, batch_count));
+        HOST_MEMCHECK(host_strided_batch_vector<T>, rparams, (5, 1, stride_param, batch_count));
 
         const int TEST_COUNT = 100;
         int test_count = !(arg.api & c_API_64) ? TEST_COUNT : 1; // only test 1 64bit API sizes
@@ -265,15 +252,22 @@ void testing_rotmg_strided_batched(const Arguments& arg)
 
                 if(arg.repeatability_check)
                 {
-                    host_strided_batch_vector<T> rd1_copy(1, 1, stride_d1, batch_count);
-                    host_strided_batch_vector<T> rd2_copy(1, 1, stride_d2, batch_count);
-                    host_strided_batch_vector<T> rx_copy(1, 1, stride_x, batch_count);
-                    host_strided_batch_vector<T> ry_copy(1, 1, stride_y, batch_count);
-                    host_strided_batch_vector<T> rparams_copy(5, 1, stride_param, batch_count);
+                    HOST_MEMCHECK(
+                        host_strided_batch_vector<T>, rd1_copy, (1, 1, stride_d1, batch_count));
+                    HOST_MEMCHECK(
+                        host_strided_batch_vector<T>, rd2_copy, (1, 1, stride_d2, batch_count));
+                    HOST_MEMCHECK(
+                        host_strided_batch_vector<T>, rx_copy, (1, 1, stride_x, batch_count));
+                    HOST_MEMCHECK(
+                        host_strided_batch_vector<T>, ry_copy, (1, 1, stride_y, batch_count));
+                    HOST_MEMCHECK(host_strided_batch_vector<T>,
+                                  rparams_copy,
+                                  (5, 1, stride_param, batch_count));
 
                     // multi-GPU support
                     int device_id, device_count;
-                    CHECK_HIP_ERROR(hipGetDeviceCount(&device_count));
+                    CHECK_HIP_ERROR(limit_device_count(device_count, (int)arg.devices));
+
                     for(int dev_id = 0; dev_id < device_count; dev_id++)
                     {
                         CHECK_HIP_ERROR(hipGetDevice(&device_id));
@@ -284,19 +278,19 @@ void testing_rotmg_strided_batched(const Arguments& arg)
                         rocblas_local_handle handle_copy{arg};
 
                         // Allocate device memory in new device
-                        device_strided_batch_vector<T> dd1_copy(1, 1, stride_d1, batch_count);
-                        device_strided_batch_vector<T> dd2_copy(1, 1, stride_d2, batch_count);
-                        device_strided_batch_vector<T> dx_copy(1, 1, stride_x, batch_count);
-                        device_strided_batch_vector<T> dy_copy(1, 1, stride_y, batch_count);
-                        device_strided_batch_vector<T> dparams_copy(
-                            5, 1, stride_param, batch_count);
-
-                        // Check device memory allocation
-                        CHECK_DEVICE_ALLOCATION(dd1_copy.memcheck());
-                        CHECK_DEVICE_ALLOCATION(dd2_copy.memcheck());
-                        CHECK_DEVICE_ALLOCATION(dx_copy.memcheck());
-                        CHECK_DEVICE_ALLOCATION(dy_copy.memcheck());
-                        CHECK_DEVICE_ALLOCATION(dparams_copy.memcheck());
+                        DEVICE_MEMCHECK(device_strided_batch_vector<T>,
+                                        dd1_copy,
+                                        (1, 1, stride_d1, batch_count));
+                        DEVICE_MEMCHECK(device_strided_batch_vector<T>,
+                                        dd2_copy,
+                                        (1, 1, stride_d2, batch_count));
+                        DEVICE_MEMCHECK(
+                            device_strided_batch_vector<T>, dx_copy, (1, 1, stride_x, batch_count));
+                        DEVICE_MEMCHECK(
+                            device_strided_batch_vector<T>, dy_copy, (1, 1, stride_y, batch_count));
+                        DEVICE_MEMCHECK(device_strided_batch_vector<T>,
+                                        dparams_copy,
+                                        (5, 1, stride_param, batch_count));
 
                         CHECK_ROCBLAS_ERROR(
                             rocblas_set_pointer_mode(handle_copy, rocblas_pointer_mode_device));
