@@ -104,6 +104,12 @@ enum class Processor : int
 // helper function in handle.cpp
 static rocblas_status free_existing_device_memory(rocblas_handle);
 
+// declare data packet methods for internal API
+ROCBLAS_INTERNAL_EXPORT_NOINLINE rocblas_status
+    rocblas_internal_set_data_ptr(rocblas_handle handle, std::shared_ptr<void>& data_ptr);
+ROCBLAS_INTERNAL_EXPORT_NOINLINE rocblas_status
+    rocblas_internal_get_data_ptr(rocblas_handle handle, std::shared_ptr<void>& data_ptr);
+
 /*******************************************************************************
  * \brief rocblas_handle is a structure holding the rocblas library context.
  * It must be initialized using rocblas_create_handle() and the returned handle mus
@@ -252,6 +258,18 @@ public:
         return archMajor == 12;
     }
 
+    int getBatchGridDim(int batch_count)
+    {
+        // c_YZ_grid_launch_limit <= min(MaxGridSize[2], MaxGridSize[3]) from hipDeviceProp.MaxGridSize[3]
+        // in file /opt/rocm/include/hip/hip_runtime_api.h
+        // This function returns a grid size that will not exceed c_YZ_grid_launch_limit
+        // for now we are using a simple constant as there is only one variability (unsigned 16-bit/32-bit)
+        if(isYZGridDim16bit())
+            return std::min(batch_count, int(c_YZ_grid_launch_limit));
+        else
+            return batch_count;
+    }
+
     bool isDefaultHipBLASLtArch()
     {
         int arch = getArch();
@@ -340,6 +358,18 @@ public:
     void                                      init_logging();
     void                                      init_check_numerics();
 
+    // data pointer for rocSOLVER
+    std::shared_ptr<void> data_ptr;
+
+    void get_data_ptr(std::shared_ptr<void>& data_ptr) const
+    {
+        data_ptr = this->data_ptr;
+    }
+    void set_data_ptr(std::shared_ptr<void>& data_ptr)
+    {
+        this->data_ptr = data_ptr;
+    }
+
     // C interfaces for manipulating device memory
     friend rocblas_status(::rocblas_start_device_memory_size_query)(_rocblas_handle*);
     friend rocblas_status(::rocblas_stop_device_memory_size_query)(_rocblas_handle*, size_t*);
@@ -434,7 +464,12 @@ public:
             hipError_t status = hipStreamIsCapturing(stream, &capture_status);
             if(status != hipSuccess)
             {
-                PRINT_IF_HIP_ERROR(status);
+                //Avoid warning users about hipErrorContextIsDestroyed error on a destroyed stream,
+                //as it may not be in capture mode, and such notifications would be unnecessary.
+                if(status != hipErrorContextIsDestroyed)
+                {
+                    PRINT_IF_HIP_ERROR(status);
+                }
                 return false;
             }
         }
@@ -716,7 +751,7 @@ private:
 
     // Allocate workspace for GSU based on the needs.
     // clang-format off
-    class [[nodiscard]] _gsu_malloc_by_size final : _device_malloc
+    class [[nodiscard]] _gsu_malloc_by_size final : public _device_malloc
     {
     public:
         explicit _gsu_malloc_by_size(rocblas_handle handle, size_t requested_Workspace_Size)
